@@ -31,6 +31,7 @@ import numpy as np
 from osgeo import gdal, gdalnumeric, ogr, osr, gdal_array
 from gdalconst import *
 from skimage.measure import block_reduce
+from skimage.transform import resize
 import matplotlib.pyplot as plt
 import pandas as pd
 
@@ -207,7 +208,7 @@ class GeoRaster():
         Usage:
             geo=GeoRaster(raster, geot, nodata_value = ndv)
         where
-            raster: Numpy masked array with the raster data, which could be loaded with the load_tiff(file)
+            raster: Numpy masked array with the raster data, which could be loaded with from_file(file) or load_tiff(file)
             geot: GDAL Geotransformation
             nodata_value: No data value in raster, optional
         '''
@@ -661,6 +662,30 @@ class GeoRaster():
         return GeoRaster(raster2, self.geot, nodata_value=self.nodata_value,\
                         projection=self.projection, datatype = self.datatype)
 
+    def resize(self, block_size, order=0, mode='constant', cval=False):
+        '''
+        geo.resize(new_shape, order=0, mode='constant', cval=np.nan)
+        
+        Returns resized georaster
+        '''
+        if not cval:
+            cval=np.nan
+        if self.raster.dtype.name.find('float')!=-1 and np.max(np.abs([self.max(),self.min()]))>1:
+            raster2=(self.raster-self.min())/(self.max()-self.min())
+        else:
+            raster2=self.raster.copy()
+        raster2=raster2.astype(float)
+        raster2[self.raster.mask]=np.nan
+        raster2=resize(raster2,block_size,order=order, mode=mode, cval=cval)
+        raster2=np.ma.masked_array(raster2, mask=np.isnan(raster2), fill_value=self.raster.fill_value)
+        raster2=raster2*(self.max()-self.min())+self.min()
+        raster2[raster2.mask]=self.nodata_value
+        raster2.mask=raster2.data==self.nodata_value
+        geot=list(self.geot)
+        [geot[-1],geot[1]]=np.array([geot[-1],geot[1]])*self.shape/block_size
+        return GeoRaster(raster2, tuple(geot), nodata_value=self.nodata_value,\
+                        projection=self.projection, datatype = self.datatype)
+
 # Union of rasters
 def union(rasters):
     """
